==> jc-1.4.0.tar.gz: javax/swing/text/JTextComponent__24DefaultTransferHandler.h <==
// class javax.swing.text.JTextComponent$DefaultTransferHandler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3fd9cbaa8bbd9473 javax_swing_TransferHandler
// @dep_class 1a2e6b13499b84e0 javax_swing_text_JTextComponent__24DefaultTransferHandler

// header file dependencies
// @dep_header javax_swing_TransferHandler

#include "javax/swing/TransferHandler.h"

#ifndef _JC_javax_swing_text_JTextComponent__24DefaultTransferHandler_H_
#define _JC_javax_swing_text_JTextComponent__24DefaultTransferHandler_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_Clipboard$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_text_JTextComponent$object;

// Typedefs
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_refs	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_refs;
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_nonrefs	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$refs	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$refs;
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$nonrefs	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object;

typedef const struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vmethods	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vmethods;
typedef const struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtable	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtable;
typedef const struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype;

// Constructors
extern void _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$_init$cf59764482b8b606(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_text_JTextComponent$object *);

// Virtual methods
extern jboolean _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$canImport$43359f3d207220c9(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_object_array *);
extern void _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$exportToClipboard$fa7eb99d07bd0e88(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_java_awt_datatransfer_Clipboard$object *, jint);
extern jint _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$getSourceActions$44890a2fb3cc6b8e(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *);
extern jboolean _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$importData$cd728ccbdf6f7838(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method_info$canImport$43359f3d207220c9;
extern _jc_method _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method_info$exportToClipboard$fa7eb99d07bd0e88;
extern _jc_method _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method_info$getSourceActions$44890a2fb3cc6b8e;
extern _jc_method _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method_info$importData$cd728ccbdf6f7838;

// Virtual methods structure
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vmethods {
	jboolean	(*canImport$43359f3d207220c9)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_object_array *);
	void	(*exportToClipboard$fa7eb99d07bd0e88)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_java_awt_datatransfer_Clipboard$object *, jint);
	jint	(*getSourceActions$44890a2fb3cc6b8e)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *);
	jboolean	(*importData$cd728ccbdf6f7838)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_object *);
};

// Vtable
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_TransferHandler$vmethods	javax_swing_TransferHandler;
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vmethods	javax_swing_text_JTextComponent__24DefaultTransferHandler;
};

// Vtype
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_refs {
	struct _jc_javax_swing_text_JTextComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$refs {
    _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_refs	javax_swing_text_JTextComponent__24DefaultTransferHandler;
    _jc_javax_swing_TransferHandler$sub_refs	javax_swing_TransferHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_TransferHandler$sub_nonrefs	javax_swing_TransferHandler;
    _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_nonrefs	javax_swing_text_JTextComponent__24DefaultTransferHandler;
};

// Object instance structure
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object {
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype	*vtype;
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_JTextComponent__24DefaultTransferHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$class_object;

#endif	/* _JC_javax_swing_text_JTextComponent__24DefaultTransferHandler_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/JTextComponent__24DefaultTransferHandler.h <==
// class javax.swing.text.JTextComponent$DefaultTransferHandler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ab3d7aa7395e69 javax_swing_TransferHandler
// @dep_class db3f8b7f45560cab javax_swing_text_JTextComponent__24DefaultTransferHandler

// header file dependencies
// @dep_header javax_swing_TransferHandler

#include "javax/swing/TransferHandler.h"

#ifndef _JC_javax_swing_text_JTextComponent__24DefaultTransferHandler_H_
#define _JC_javax_swing_text_JTextComponent__24DefaultTransferHandler_H_

// Forward structure declarations
struct _jc_java_awt_datatransfer_Clipboard$object;
struct _jc_java_awt_datatransfer_Transferable$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_text_JTextComponent$object;

// Typedefs
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_refs	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_refs;
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_nonrefs	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$refs	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$refs;
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$nonrefs	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object;

typedef const struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vmethods	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vmethods;
typedef const struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtable	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtable;
typedef const struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype;

// Constructors
extern void _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$_init$cf59764482b8b606(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_text_JTextComponent$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$canImport$43359f3d207220c9(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$exportToClipboard$fa7eb99d07bd0e88(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_java_awt_datatransfer_Clipboard$object *, jint) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$getSourceActions$44890a2fb3cc6b8e(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method$importData$cd728ccbdf6f7838(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method_info$canImport$43359f3d207220c9;
extern _jc_method _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method_info$exportToClipboard$fa7eb99d07bd0e88;
extern _jc_method _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method_info$getSourceActions$44890a2fb3cc6b8e;
extern _jc_method _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$method_info$importData$cd728ccbdf6f7838;

// Virtual methods structure
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vmethods {
	jboolean	(*canImport$43359f3d207220c9)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	void	(*exportToClipboard$fa7eb99d07bd0e88)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_java_awt_datatransfer_Clipboard$object *, jint) _JC_JCNI_ATTR;
	jint	(*getSourceActions$44890a2fb3cc6b8e)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *) _JC_JCNI_ATTR;
	jboolean	(*importData$cd728ccbdf6f7838)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object *, struct _jc_javax_swing_JComponent$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_TransferHandler$vmethods	javax_swing_TransferHandler;
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vmethods	javax_swing_text_JTextComponent__24DefaultTransferHandler;
};

// Vtype
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype {
	_jc_type			type;
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_refs {
	struct _jc_javax_swing_text_JTextComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$refs {
    _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_refs	javax_swing_text_JTextComponent__24DefaultTransferHandler;
    _jc_javax_swing_TransferHandler$sub_refs	javax_swing_TransferHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_TransferHandler$sub_nonrefs	javax_swing_TransferHandler;
    _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$sub_nonrefs	javax_swing_text_JTextComponent__24DefaultTransferHandler;
};

// Object instance structure
struct _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$object {
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype	*vtype;
	_jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$vtype _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_JTextComponent__24DefaultTransferHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_JTextComponent__24DefaultTransferHandler$class_object;

#endif	/* _JC_javax_swing_text_JTextComponent__24DefaultTransferHandler_H_ */
